
function AssembleGlobalMatrix(e,Ke,fe);
include_variables;

% Here we assemble element stiffness matrices (and load vectors) 
%
% Parameters:
%   Input, e  -- element number
%   Input, Ke -- element stiffness matrix
%   Input, fe -- element load vector

% Each node has ndof degrees of freedom. The degrees of freedom are
% numbered sequentially for x, y ,z directions starting from node 1. Thus, 
% for the ith node the degrees of freedom are (i-1)*ndof + a, a = 1,..ndof.

for i = 1 : nen
    for a = 1 : ndof
        loci = (i-1)*ndof + a;                      %local row index
        glbi = ndof*(Elems(i,e) - 1) + a;           %global row index
       
        if ( fe(loci)~=0 )
            f(glbi) = f(glbi) + fe(loci);           % assemble load
        end
        for j = 1 : nen
            for b = 1 : ndof
                locj = (j-1)*ndof + b;              %local column index
                glbj = ndof*(Elems(j,e) - 1) + b;   %global column index

                if ( Ke(loci,locj) ~= 0)            % set up the list of triplets
                    ntriplets = ntriplets + 1;
                                        
                    len = length(X);                % Manually increase the size of the I,J,X arrays
                                                    % if needed. MATLAB can automatically increase 
                                                    % the size of the arrays by 1. However,this 
                                                    % process is speeded up if the size of these
                                                    % arrays is re-assigned as done here. 

                    if ( ntriplets > len)           % All the values of these arrays between len & 2*len 
                        I(2*len) = 0;               % are set to zero and the length of these arrays 
                        J(2*len) = 0;               % is increased to 2* len 
                        X(2*len) = 0;
                    end

                    I(ntriplets) = glbi;
                    J(ntriplets) = glbj;
                    X(ntriplets) = Ke(loci,locj);

                end
            end
        end
    end
end



