

function [d, rf] = NodalSoln(K, R, debc, ebcVals)

% To solve for the nodal displacements you first need to apply 
% the essential boundary conditions on the KD=R system of equations. 
% 
% Here we compute the nodal displacement solution and nodal reactions
%
% K = global stiffness matrix
% R = global right hand side vector
%
% debc = list of degrees of freedom with specified values
% ebcVals = specified displacement values


dof = length(R);                % Extract the total degreess-of-freedom


df = setdiff(1:dof, debc);      % Sets the difference between two sets of indices, i.e.
                                % the global degrees of freedom minus the degrees of 
                                % freedom with prescribed essential
                                % boundary conditions

Kf = K(df, df);                 % Remove eqs. corresponding to prescribed displacements

Rf = R(df) - K(df, debc)*ebcVals; % Modify the remaining load vector to account for
                                  % the essential boundary conditions



dfVals = Kf\Rf;                 % Solve the linear system of equations
                                % Here we simplicity we use Gauss
                                % elimination.
                                % The whole idea of introducing sparse matrix
                                % representation of the stiffness matric was to 
                                % explore other more efficient solvers for systems
                                % of large size -- this is something you may want to 
                                % play with!


d = zeros(dof,1);               % Restore the solution vector (i.e. include back the 
d(debc) = ebcVals;              % nodes with prescribed displacement). Use the originally
d(df) = dfVals;                 % established ordering of the nodes. 

rf = K(debc,:)*d - R(debc);     % Calculate the reaction vector


