
% File to include global variables

% nno :           number of total nodes
% nel :           number of total elements
% nen :           number of nodes on each element
% ndof:           degrees-of-freedom per node
% neq :           number of equations

global nno nel nen ndof neq 

% Nodes:          Coordinates information matrix. Nodes(i,j) denotes the
%                 coordinates in the ith direction on the jth node.

% Elems:          Connectivity information matrix. 
%                 global node number = Elems(local node number, element number) 


global Nodes Elems 

% K    :          Global stiffness matrix (in a sparse matrix format)
% d    :          Global solution vector
% f    :          Global load vector
% r    :          Reaction forces

global K d f r

% variables to assemble the sparse finite elemnt matrix
% I - an array containing the row index of nonzero entry
% J - an array containing the column index of nonzero entry
% X - an array containing the value of nonzero entry
% ntriplets -  a global variable to trace the index

% The idea here is to create a list of triplets, and let MATLAB convert
% them into a sparse matrix all at once. If there are duplicates (which a
% finite element matrix always has) the duplicates are summed, which is
% exactly what we want when assembling a finite-element matrix.

global I J X ntriplets

% EI = modulus of elasticity x moment of inertia for each beam element
% p = uniform distributed load (adjust for other load conditions)

global EI p

global debc ebcVals  % debc = degrees of freedom with EB conditions
                     % ebcVals = values of the prescribed EB conditions




